==> 0.3.5.tar.gz: test/do2template_test.dart <==
// Copyright (c) 2015, Mikhail Stolyarov. All rights reserved. Use of this source code
// is governed by a BSD-style license that can be found in the LICENSE file.
@TestOn('browser')
library do2template.test;

import 'dart:html';
import "package:test/test.dart";

import 'package:do2template/do2template.dart';


main() {

  Do2Template.nodeValidator..allowElement('p', attributes:['role']);

  group('Do2Template', () {
    test('new Object', (){
      Do2Template template = new Do2Template('<do2template><div><p role="test">Hello</p></div></do2template>');
      expect(template.html, equals('<do2template><div><p role="test">Hello</p></div></do2template>'));
      expect(template.getTemplate() is Do2Html, isTrue);
    });

    test('Loading html', () async {
      Do2Template template = await Do2Template.loadingHtml(Uri.parse('template/test.html'));
      expect(template.html, isNotEmpty);
      expect(template.getTemplate() is Do2Html, isTrue);
    });

    test('Bind', () {
      Do2Template template = new Do2Template('<do2template><div><p role="test">Hello</p></div></do2template>');
      Element div = new DivElement();
      Element p;
      template.bind.add((Element e)=> p = e.querySelector('p'));
      template.getTemplate().draw(div);
      expect(div.innerHtml, equals('<div><p role="test">Hello</p></div>'));
      expect(p.innerHtml, equals('Hello'));
      p.innerHtml = 'Bye';
      expect(div.innerHtml, equals('<div><p role="test">Bye</p></div>'));
    });

  });

  group('Do2Html', (){

    Do2Html html = new Do2Template('<do2template><div><p role="test">Hello</p></div></do2template>').getTemplate();
    Element div = new DivElement();

    test('Draw', (){
      div.children.add(new DivElement());
      html.draw(div);
      expect(div.innerHtml, equals('<div></div><div><p role="test">Hello</p></div>'));
    });

    test('Eraser', (){
      html.eraser();
      expect(div.innerHtml, equals('<div></div>'));
    });

    test('Duble Draw', (){
      Do2Html htmlone = new Do2Template('<do2template><div><p role="test">Hello</p></div></do2template>').getTemplate();
      Element div1 = new DivElement();
      Element div2 = new DivElement();
      htmlone.draw(div1);
      htmlone.draw(div2);
      expect(div1.innerHtml, equals('<div><p role="test">Hello</p></div>'));
      expect(div2.innerHtml, equals(''));
    });

    test('Query', (){
      Do2Html html = new Do2Template('<do2template><div><p class="select">Test</p></div><div><p class="select two">Test Two</p></div></do2template>').getTemplate();
      expect(html.query('.select').innerHtml, equals('Test'));
      expect(html.query('.two').innerHtml, equals('Test Two'));
      expect(html.query('.noClass'), isNull);
    });

    test('QueryAll', (){
      Do2Html html = new Do2Template('<do2template><div><p class="select">Test</p></div><div><p class="select two">Test Two</p></div></do2template>').getTemplate();
      List<Element> element = html.queryAll('.select');
      expect(element.length, equals(2));
      expect(element[0].innerHtml, equals('Test'));
      expect(element[1].innerHtml, equals('Test Two'));
      expect(html.queryAll('.noClass'), isEmpty);
    });

  });

  group('Do2Repeat', (){

    Do2Html html = new Do2Template('<do2template><table><thead><tr><th>№</th><th>Потребитель</th></tr></thead><tbody><tr do2repeat = "client"><th do2repeat-field="id"></th><td do2repeat-field="name"></td></tr></tbody></table></do2template>').getTemplate();
    Element div = new DivElement();

    test('Create', (){
      html.draw(div);
      expect(div.innerHtml, equals('<table><thead><tr><th>№</th><th>Потребитель</th></tr></thead><tbody></tbody></table>'));
      expect(html.repeat.length, equals(1));
    });

    test('Repeat Text', (){
      html.repeat['client'].repeatText([{'id':'1', 'name':'Вася'},{'id':'2', 'name':'Дима'},{'id':'3', 'name':'Саша'}]);
      expect(div.querySelectorAll('[do2repeat=client]').length, equals(3));
    });

    test('Repeat eraser Text', (){
      html.repeat['client'].eraserText();
      expect(div.innerHtml, equals('<table><thead><tr><th>№</th><th>Потребитель</th></tr></thead><tbody></tbody></table>'));
    });

    test('Repeat Element', (){
      html.repeat['client'].repeatElement([{'id':new Element.html('<b>1</b>'), 'name':new Element.html('<b>Вася</b>')},{'id':new Element.html('<b>2</b>'), 'name':new Element.html('<b>Вася</b>')},{'id':new Element.html('<b>3</b>'), 'name':new Element.html('<b>Вася</b>')}]);
      expect(div.querySelectorAll('[do2repeat=client').length, equals(3));
    });

    test('Repeat eraser Element', (){
      html.repeat['client'].eraserElement();
      expect(div.innerHtml, equals('<table><thead><tr><th>№</th><th>Потребитель</th></tr></thead><tbody></tbody></table>'));
    });

  });

}

==> 0.4.1.tar.gz: test/do2template_test.dart <==
// Copyright (c) 2015, Mikhail Stolyarov. All rights reserved. Use of this source code
// is governed by a BSD-style license that can be found in the LICENSE file.
@TestOn('browser')
library do2template.test;

import 'dart:html';
import "package:test/test.dart";

import 'package:do2template/do2template.dart';


main() {

  Do2Template.nodeValidator..allowElement('p', attributes:['role']);

  group('Do2Template', () {
    test('new Object', (){
      Do2Template template = new Do2Template('<do2template><div><p role="test">Hello</p></div></do2template>');
      expect(template.html, equals('<do2template><div><p role="test">Hello</p></div></do2template>'));
      expect(template.getTemplate() is Do2Html, isTrue);
    });

    test('Loading html', () async {
      Do2Template template = await Do2Template.loadingHtml(Uri.parse('template/test.html'));
      expect(template.html, isNotEmpty);
      expect(template.getTemplate() is Do2Html, isTrue);
    });

    test('Bind', () {
      Do2Template template = new Do2Template('<do2template><div><p role="test">Hello</p></div></do2template>');
      Element div = new DivElement();
      Element p;
      template.bind.add((Element e)=> p = e.querySelector('p'));
      template.getTemplate().draw(div);
      expect(div.innerHtml, equals('<div><p role="test">Hello</p></div>'));
      expect(p.innerHtml, equals('Hello'));
      p.innerHtml = 'Bye';
      expect(div.innerHtml, equals('<div><p role="test">Bye</p></div>'));
    });

  });

  group('Do2Html', (){

    Do2Html html = new Do2Template('<do2template><div><p role="test">Hello</p></div></do2template>').getTemplate();
    Element div = new DivElement();

    test('Draw', (){
      div.children.add(new DivElement());
      html.draw(div);
      expect(div.innerHtml, equals('<div></div><div><p role="test">Hello</p></div>'));
    });

    test('Eraser', (){
      html.eraser();
      expect(div.innerHtml, equals('<div></div>'));
    });

    test('Duble Draw', (){
      Do2Html htmlone = new Do2Template('<do2template><div><p role="test">Hello</p></div></do2template>').getTemplate();
      Element div1 = new DivElement();
      Element div2 = new DivElement();
      htmlone.draw(div1);
      htmlone.draw(div2);
      expect(div1.innerHtml, equals('<div><p role="test">Hello</p></div>'));
      expect(div2.innerHtml, equals(''));
    });

  });

  group('Do2Repeat', (){

    Do2Html html = new Do2Template('<do2template><table><thead><tr><th>№</th><th>Потребитель</th></tr></thead><tbody><tr do2repeat = "client"><th do2repeat-field="id"></th><td do2repeat-field="name"></td></tr></tbody></table></do2template>').getTemplate();
    Element div = new DivElement();

    test('Create', (){
      html.draw(div);
      expect(div.innerHtml, equals('<table><thead><tr><th>№</th><th>Потребитель</th></tr></thead><tbody></tbody></table>'));
      expect(html.repeat.length, equals(1));
    });

    test('Repeat Text', (){
      html.repeat['client'].repeatText([{'id':'1', 'name':'Вася'},{'id':'2', 'name':'Дима'},{'id':'3', 'name':'Саша'}]);
      expect(div.querySelectorAll('[do2repeat=client]').length, equals(3));
    });

    test('Repeat eraser Text', (){
      html.repeat['client'].eraserText();
      expect(div.innerHtml, equals('<table><thead><tr><th>№</th><th>Потребитель</th></tr></thead><tbody></tbody></table>'));
    });

    test('Repeat Element', (){
      html.repeat['client'].repeatElement([{'id':new Element.html('<b>1</b>'), 'name':new Element.html('<b>Вася</b>')},{'id':new Element.html('<b>2</b>'), 'name':new Element.html('<b>Вася</b>')},{'id':new Element.html('<b>3</b>'), 'name':new Element.html('<b>Вася</b>')}]);
      expect(div.querySelectorAll('[do2repeat=client').length, equals(3));
    });

    test('Repeat eraser Element', (){
      html.repeat['client'].eraserElement();
      expect(div.innerHtml, equals('<table><thead><tr><th>№</th><th>Потребитель</th></tr></thead><tbody></tbody></table>'));
    });

  });

  group('Do2Translation', (){
    Do2Html html = new Do2Template('<do2template><p do2lang="ru">Привет</p></do2template>').getTemplate();
    Element div = new DivElement();

    test('Create', (){
      html.draw(div);
      expect(div.innerHtml, equals('<p do2lang="ru">Привет</p>'));
      expect(html.lang.getLangs()['ru'][0].innerHtml, equals('Привет'));
    });

  });

}
